@@ -17,31 +17,12 @@
 
 package org.apache.hertzbeat.manager.service.impl;
 
-import static java.util.Objects.isNull;
-import java.io.File;
-import java.io.FileInputStream;
-import java.io.IOException;
-import java.nio.charset.StandardCharsets;
-import java.util.ArrayList;
-import java.util.Collections;
-import java.util.HashMap;
-import java.util.HashSet;
-import java.util.LinkedList;
-import java.util.List;
-import java.util.Map;
-import java.util.Objects;
-import java.util.Optional;
-import java.util.Set;
-import java.util.concurrent.ConcurrentHashMap;
-import java.util.stream.Collectors;
-import javax.annotation.Resource;
 import lombok.extern.slf4j.Slf4j;
 import org.apache.commons.io.FileUtils;
 import org.apache.commons.io.IOUtils;
 import org.apache.commons.lang3.StringUtils;
 import org.apache.hertzbeat.collector.dispatch.DispatchConstants;
 import org.apache.hertzbeat.collector.util.CollectUtil;
-import org.apache.hertzbeat.common.constants.JexlKeywordsEnum;
 import org.apache.hertzbeat.common.entity.job.Configmap;
 import org.apache.hertzbeat.common.entity.job.Job;
 import org.apache.hertzbeat.common.entity.job.Metrics;
@@ -53,6 +34,8 @@ import org.apache.hertzbeat.common.entity.message.CollectRep;
 import org.apache.hertzbeat.common.support.SpringContextHolder;
 import org.apache.hertzbeat.common.support.exception.CommonException;
 import org.apache.hertzbeat.common.util.CommonUtil;
+import org.apache.hertzbeat.common.util.HertzBeatKeywordsUtil;
+import org.apache.hertzbeat.common.util.JexlCheckerUtil;
 import org.apache.hertzbeat.manager.dao.DefineDao;
 import org.apache.hertzbeat.manager.dao.MonitorDao;
 import org.apache.hertzbeat.manager.dao.ParamDao;
@@ -74,6 +57,26 @@ import org.springframework.util.Assert;
 import org.springframework.util.StreamUtils;
 import org.yaml.snakeyaml.Yaml;
 
+import javax.annotation.Resource;
+import java.io.File;
+import java.io.FileInputStream;
+import java.io.IOException;
+import java.nio.charset.StandardCharsets;
+import java.util.ArrayList;
+import java.util.Collections;
+import java.util.HashMap;
+import java.util.HashSet;
+import java.util.LinkedList;
+import java.util.List;
+import java.util.Map;
+import java.util.Objects;
+import java.util.Optional;
+import java.util.Set;
+import java.util.concurrent.ConcurrentHashMap;
+import java.util.stream.Collectors;
+
+import static java.util.Objects.isNull;
+
 /**
  * Monitoring Type Management Implementation
  * Temporarily stores the monitoring configuration and parameter configuration in memory,
@@ -437,32 +440,34 @@ public class AppServiceImpl implements AppService, InitializingBean {
         for (ParamDefine param : app.getParams()) {
             CommonUtil.validDefineI18n(param.getName(),  param.getField() + " param");
         }
-        for (Metrics metric : app.getMetrics()) {
-            CommonUtil.validDefineI18n(metric.getI18n(), metric.getName() + " metric");
-            if (metric.getFields() == null){
-                continue;
-            }
-            for (Metrics.Field field : metric.getFields()) {
-                CommonUtil.validDefineI18n(field.getI18n(), metric.getName() + " metric " + field.getField() + " field");
-            }
-        }
         if (!isModify) {
             Assert.isNull(appDefines.get(app.getApp().toLowerCase()),
                     "monitoring template name " + app.getApp() + " already exists.");
         }
         Set<String> fieldsSet = new HashSet<>(16);
         for (Metrics metrics : app.getMetrics()) {
+            CommonUtil.validDefineI18n(metrics.getI18n(), metrics.getName() + " metric");
             Assert.notEmpty(metrics.getFields(), "monitoring template metrics fields can not null");
             fieldsSet.clear();
             for (Metrics.Field field : metrics.getFields()) {
+                CommonUtil.validDefineI18n(field.getI18n(), metrics.getName() + " metric " + field.getField() + " field");
+                HertzBeatKeywordsUtil.verifyKeywords(field.getField());
                 if (fieldsSet.contains(field.getField())) {
                     throw new IllegalArgumentException(app.getApp() + " " + metrics.getName() + " " 
                             + field.getField() + " can not duplicated.");
                 }
-                if (JexlKeywordsEnum.match(field.getField())) {
+                if (JexlCheckerUtil.verifyKeywords(field.getField())) {
                     throw new IllegalArgumentException(app.getApp() + " " + metrics.getName() + " "
                             + field.getField() + " prohibited keywords.");
                 }
+                if (JexlCheckerUtil.verifyStartCharacter(field.getField())) {
+                    throw new IllegalArgumentException(app.getApp() + " " + metrics.getName() + " "
+                            + field.getField() + " illegal start character.");
+                }
+                if (JexlCheckerUtil.verifySpaces(field.getField())) {
+                    throw new IllegalArgumentException(app.getApp() + " " + metrics.getName() + " "
+                            + field.getField() + " no spaces allowed.");
+                }
                 fieldsSet.add(field.getField());
             }
         }
