@@ -6,7 +6,7 @@
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ * http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -21,7 +21,6 @@ import java.io.ByteArrayOutputStream;
 import java.math.BigDecimal;
 import java.math.RoundingMode;
 import java.net.URI;
-import java.net.URLEncoder;
 import java.nio.charset.StandardCharsets;
 import java.time.Duration;
 import java.time.ZonedDateTime;
@@ -86,7 +85,7 @@ public class VictoriaMetricsDataStorage extends AbstractHistoryDataStorage {
     private static final String IMPORT_PATH = "/api/v1/import";
     /**
      * <a href="https://docs.victoriametrics.com/Single-server-VictoriaMetrics.html#how-to-export-data-in-json-line-format">
-     *     https://docs.victoriametrics.com/Single-server-VictoriaMetrics.html#how-to-export-data-in-json-line-format
+     * https://docs.victoriametrics.com/Single-server-VictoriaMetrics.html#how-to-export-data-in-json-line-format
      * </a>
      */
     private static final String EXPORT_PATH = "/api/v1/export";
@@ -95,7 +94,7 @@ public class VictoriaMetricsDataStorage extends AbstractHistoryDataStorage {
     private static final String LABEL_KEY_NAME = "__name__";
     private static final String LABEL_KEY_JOB = "job";
     private static final String LABEL_KEY_INSTANCE = "instance";
-    private static final String LABEL_KEY_HOST = "host";
+    private static final String LABEL_KEY_MONITOR_ID = "__monitor_id__";
     private static final String SPILT = "_";
     private static final String MONITOR_METRICS_KEY = "__metrics__";
     private static final String MONITOR_METRIC_KEY = "__metric__";
@@ -105,7 +104,7 @@ public class VictoriaMetricsDataStorage extends AbstractHistoryDataStorage {
     private final VictoriaMetricsProperties victoriaMetricsProp;
     private final RestTemplate restTemplate;
     private final BlockingQueue<VictoriaMetricsDataStorage.VictoriaMetricsContent> metricsBufferQueue;
-    
+
     private HashedWheelTimer metricsFlushTimer = null;
     private final VictoriaMetricsProperties.InsertConfig insertConfig;
     private final AtomicBoolean draining = new AtomicBoolean(false);
@@ -119,7 +118,7 @@ public class VictoriaMetricsDataStorage extends AbstractHistoryDataStorage {
         victoriaMetricsProp = victoriaMetricsProperties;
         serverAvailable = checkVictoriaMetricsDatasourceAvailable();
         insertConfig = victoriaMetricsProperties.insert() == null ? new VictoriaMetricsProperties.InsertConfig(100, 3,
-                new VictoriaMetricsProperties.Compression(false)) : victoriaMetricsProperties.insert();
+            new VictoriaMetricsProperties.Compression(false)) : victoriaMetricsProperties.insert();
         metricsBufferQueue = new LinkedBlockingQueue<>(insertConfig.bufferSize());
         initializeFlushTimer();
     }
@@ -139,14 +138,14 @@ public class VictoriaMetricsDataStorage extends AbstractHistoryDataStorage {
         try {
             HttpHeaders headers = new HttpHeaders();
             if (StringUtils.hasText(victoriaMetricsProp.username())
-                    && StringUtils.hasText(victoriaMetricsProp.password())) {
+                && StringUtils.hasText(victoriaMetricsProp.password())) {
                 String authStr = victoriaMetricsProp.username() + SignConstants.DOUBLE_MARK + victoriaMetricsProp.password();
                 String encodedAuth = Base64Util.encode(authStr);
                 headers.add(HttpHeaders.AUTHORIZATION,  NetworkConstants.BASIC + " " + encodedAuth);
             }
             HttpEntity<Void> httpEntity = new HttpEntity<>(headers);
             ResponseEntity<String> responseEntity = restTemplate.exchange(victoriaMetricsProp.url() + STATUS_PATH,
-                    HttpMethod.GET, httpEntity, String.class);
+                HttpMethod.GET, httpEntity, String.class);
             if (responseEntity.getStatusCode().is2xxSuccessful()) {
                 log.info("check victoria metrics server status success.");
                 return true;
@@ -168,7 +167,7 @@ public class VictoriaMetricsDataStorage extends AbstractHistoryDataStorage {
         }
         if (metricsData.getValues().isEmpty()) {
             log.info("[warehouse victoria-metrics] flush metrics data {} {} {} is null, ignore.",
-                    metricsData.getId(), metricsData.getApp(), metricsData.getMetrics());
+                metricsData.getId(), metricsData.getApp(), metricsData.getMetrics());
             return;
         }
         Map<String, String> defaultLabels = Maps.newHashMapWithExpectedSize(8);
@@ -178,11 +177,11 @@ public class VictoriaMetricsDataStorage extends AbstractHistoryDataStorage {
             isPrometheusAuto = true;
             defaultLabels.remove(MONITOR_METRICS_KEY);
             defaultLabels.put(LABEL_KEY_JOB, metricsData.getApp()
-                    .substring(CommonConstants.PROMETHEUS_APP_PREFIX.length()));
+                .substring(CommonConstants.PROMETHEUS_APP_PREFIX.length()));
         } else {
             defaultLabels.put(LABEL_KEY_JOB, metricsData.getApp());
         }
-        defaultLabels.put(LABEL_KEY_INSTANCE, String.valueOf(metricsData.getId()));
+        defaultLabels.put(LABEL_KEY_INSTANCE, metricsData.getInstance());
 
 
         List<VictoriaMetricsContent> contentList = new LinkedList<>();
@@ -220,22 +219,22 @@ public class VictoriaMetricsDataStorage extends AbstractHistoryDataStorage {
                         try {
                             labels.putAll(defaultLabels);
                             String labelName = isPrometheusAuto ? metricsData.getMetrics()
-                                    : metricsData.getMetrics() + SPILT + entry.getKey();
+                                : metricsData.getMetrics() + SPILT + entry.getKey();
                             labels.put(LABEL_KEY_NAME, labelName);
                             if (!isPrometheusAuto) {
                                 labels.put(MONITOR_METRIC_KEY, entry.getKey());
                             }
-                            labels.put(LABEL_KEY_HOST, metricsData.getInstanceHost());
+                            labels.put(LABEL_KEY_MONITOR_ID, String.valueOf(metricsData.getId()));
                             // add customized labels as identifier
                             var customizedLabels = metricsData.getLabels();
                             if (!ObjectUtils.isEmpty(customizedLabels)) {
                                 labels.putAll(customizedLabels);
                             }
                             VictoriaMetricsContent content = VictoriaMetricsContent.builder()
-                                    .metric(new HashMap<>(labels))
-                                    .values(new Double[]{entry.getValue()})
-                                    .timestamps(timestamp)
-                                    .build();
+                                .metric(new HashMap<>(labels))
+                                .values(new Double[]{entry.getValue()})
+                                .timestamps(timestamp)
+                                .build();
                             contentList.add(content);
                         } catch (Exception e) {
                             log.error("combine metrics data error: {}.", e.getMessage(), e);
@@ -264,45 +263,48 @@ public class VictoriaMetricsDataStorage extends AbstractHistoryDataStorage {
     }
 
     @Override
-    public Map<String, List<Value>> getHistoryMetricData(Long monitorId, String app, String metrics, String metric, String label, String history) {
+    public Map<String, List<Value>> getHistoryMetricData(String instance, String app, String metrics, String metric, String history) {
         String labelName = metrics + SPILT + metric;
-        if (CommonConstants.PROMETHEUS.equals(app)) {
+        if (app.startsWith(CommonConstants.PROMETHEUS_APP_PREFIX)) {
             labelName = metrics;
         }
         String timeSeriesSelector = LABEL_KEY_NAME + "=\"" + labelName + "\""
-                + "," + LABEL_KEY_INSTANCE + "=\"" + monitorId + "\""
-                + (CommonConstants.PROMETHEUS.equals(app) ? "" : "," + MONITOR_METRIC_KEY + "=\"" + metric + "\"");
+                + "," + LABEL_KEY_INSTANCE + "=\"" + instance + "\""
+                + (app.startsWith(CommonConstants.PROMETHEUS_APP_PREFIX) ? "" : "," + MONITOR_METRIC_KEY + "=\"" + metric + "\"");
         Map<String, List<Value>> instanceValuesMap = new HashMap<>(8);
         try {
             HttpHeaders headers = new HttpHeaders();
             headers.setContentType(MediaType.APPLICATION_JSON);
             headers.setAccept(List.of(MediaType.APPLICATION_JSON));
             if (StringUtils.hasText(victoriaMetricsProp.username())
-                    && StringUtils.hasText(victoriaMetricsProp.password())) {
+                && StringUtils.hasText(victoriaMetricsProp.password())) {
                 String authStr = victoriaMetricsProp.username() + ":" + victoriaMetricsProp.password();
                 String encodedAuth = Base64Util.encode(authStr);
                 headers.add(HttpHeaders.AUTHORIZATION,  NetworkConstants.BASIC + SignConstants.BLANK + encodedAuth);
             }
             HttpEntity<Void> httpEntity = new HttpEntity<>(headers);
             URI uri = UriComponentsBuilder.fromUriString(victoriaMetricsProp.url() + EXPORT_PATH)
-                    .queryParam(URLEncoder.encode("match[]", StandardCharsets.UTF_8), URLEncoder.encode("{" + timeSeriesSelector + "}", StandardCharsets.UTF_8))
-                    .queryParam("start", URLEncoder.encode("now-" + history, StandardCharsets.UTF_8))
-                    .queryParam("end", "now")
-                    .build(true).toUri();
+                .queryParam("match[]", "{" + timeSeriesSelector + "}")
+                .queryParam("start", "now-" + history)
+                .queryParam("end", "now")
+                .build()
+                .encode()
+                .toUri();
             ResponseEntity<String> responseEntity = restTemplate.exchange(uri,
-                    HttpMethod.GET, httpEntity, String.class);
+                HttpMethod.GET, httpEntity, String.class);
             if (responseEntity.getStatusCode().is2xxSuccessful()) {
                 log.debug("query metrics data from victoria-metrics success. {}", uri);
                 if (StringUtils.hasText(responseEntity.getBody())) {
                     String[] contentJsonArr = responseEntity.getBody().split("\n");
                     List<VictoriaMetricsContent> contents = Arrays.stream(contentJsonArr).map(
-                            item ->  JsonUtil.fromJson(item, VictoriaMetricsContent.class)
+                        item ->  JsonUtil.fromJson(item, VictoriaMetricsContent.class)
                     ).toList();
                     for (VictoriaMetricsContent content : contents) {
                         Map<String, String> labels = content.getMetric();
                         labels.remove(LABEL_KEY_NAME);
                         labels.remove(LABEL_KEY_JOB);
                         labels.remove(LABEL_KEY_INSTANCE);
+                        labels.remove(LABEL_KEY_MONITOR_ID);
                         labels.remove(MONITOR_METRICS_KEY);
                         labels.remove(MONITOR_METRIC_KEY);
                         String labelStr = JsonUtil.toJson(labels);
@@ -332,11 +334,11 @@ public class VictoriaMetricsDataStorage extends AbstractHistoryDataStorage {
     }
 
     @Override
-    public Map<String, List<Value>> getHistoryIntervalMetricData(Long monitorId, String app, String metrics,
-                                                                 String metric, String label, String history) {
+    public Map<String, List<Value>> getHistoryIntervalMetricData(String instance, String app, String metrics,
+                                                                 String metric, String history) {
         if (!serverAvailable) {
             log.error("""
-                    
+
                     \t---------------VictoriaMetrics Init Failed---------------
                     \t--------------Please Config VictoriaMetrics--------------
                     \t----------Can Not Use Metric History Now----------
@@ -360,43 +362,46 @@ public class VictoriaMetricsDataStorage extends AbstractHistoryDataStorage {
             startTime = dateTime.toEpochSecond();
         }
         String labelName = metrics + SPILT + metric;
-        if (CommonConstants.PROMETHEUS.equals(app)) {
+        if (app.startsWith(CommonConstants.PROMETHEUS_APP_PREFIX)) {
             labelName = metrics;
         }
         String timeSeriesSelector = LABEL_KEY_NAME + "=\"" + labelName + "\""
-                + "," + LABEL_KEY_INSTANCE + "=\"" + monitorId + "\""
-                + (CommonConstants.PROMETHEUS.equals(app) ? "" : "," + MONITOR_METRIC_KEY + "=\"" + metric + "\"");
+                + "," + LABEL_KEY_INSTANCE + "=\"" + instance + "\""
+                + (app.startsWith(CommonConstants.PROMETHEUS_APP_PREFIX) ? "" : "," + MONITOR_METRIC_KEY + "=\"" + metric + "\"");
         Map<String, List<Value>> instanceValuesMap = new HashMap<>(8);
         try {
             HttpHeaders headers = new HttpHeaders();
             headers.setContentType(MediaType.APPLICATION_JSON);
             headers.setAccept(List.of(MediaType.APPLICATION_JSON));
             if (StringUtils.hasText(victoriaMetricsProp.username())
-                    && StringUtils.hasText(victoriaMetricsProp.password())) {
+                && StringUtils.hasText(victoriaMetricsProp.password())) {
                 String authStr = victoriaMetricsProp.username() + ":" + victoriaMetricsProp.password();
                 String encodedAuth = Base64Util.encode(authStr);
                 headers.add(HttpHeaders.AUTHORIZATION,  NetworkConstants.BASIC
-                        + SignConstants.BLANK + encodedAuth);
+                    + SignConstants.BLANK + encodedAuth);
             }
             HttpEntity<Void> httpEntity = new HttpEntity<>(headers);
             URI uri = UriComponentsBuilder.fromUriString(victoriaMetricsProp.url() + QUERY_RANGE_PATH)
-                    .queryParam(URLEncoder.encode("query", StandardCharsets.UTF_8), URLEncoder.encode("{" + timeSeriesSelector + "}", StandardCharsets.UTF_8))
-                    .queryParam("step", "4h")
-                    .queryParam("start", startTime)
-                    .queryParam("end", endTime)
-                    .build(true).toUri();
+                .queryParam("query", "{" + timeSeriesSelector + "}")
+                .queryParam("step", "4h")
+                .queryParam("start", startTime)
+                .queryParam("end", endTime)
+                .build()
+                .encode()
+                .toUri();
             ResponseEntity<PromQlQueryContent> responseEntity = restTemplate.exchange(uri,
-                    HttpMethod.GET, httpEntity, PromQlQueryContent.class);
+                HttpMethod.GET, httpEntity, PromQlQueryContent.class);
             if (responseEntity.getStatusCode().is2xxSuccessful()) {
                 log.debug("query metrics data from victoria-metrics success. {}", uri);
                 if (responseEntity.getBody() != null && responseEntity.getBody().getData() != null
-                        && responseEntity.getBody().getData().getResult() != null) {
+                    && responseEntity.getBody().getData().getResult() != null) {
                     List<PromQlQueryContent.ContentData.Content> contents = responseEntity.getBody().getData().getResult();
                     for (PromQlQueryContent.ContentData.Content content : contents) {
                         Map<String, String> labels = content.getMetric();
                         labels.remove(LABEL_KEY_NAME);
                         labels.remove(LABEL_KEY_JOB);
                         labels.remove(LABEL_KEY_INSTANCE);
+                        labels.remove(LABEL_KEY_MONITOR_ID);
                         labels.remove(MONITOR_METRICS_KEY);
                         labels.remove(MONITOR_METRIC_KEY);
                         String labelStr = JsonUtil.toJson(labels);
@@ -416,22 +421,25 @@ public class VictoriaMetricsDataStorage extends AbstractHistoryDataStorage {
             }
             // max
             uri = UriComponentsBuilder.fromUriString(victoriaMetricsProp.url() + QUERY_RANGE_PATH)
-                    .queryParam(URLEncoder.encode("query", StandardCharsets.UTF_8), URLEncoder.encode("max_over_time({" + timeSeriesSelector + "})", StandardCharsets.UTF_8))
-                    .queryParam("step", "4h")
-                    .queryParam("start", startTime)
-                    .queryParam("end", endTime)
-                    .build(true).toUri();
+                .queryParam("query", "max_over_time({" + timeSeriesSelector + "})")
+                .queryParam("step", "4h")
+                .queryParam("start", startTime)
+                .queryParam("end", endTime)
+                .build()
+                .encode()
+                .toUri();
             responseEntity = restTemplate.exchange(uri,
-                    HttpMethod.GET, httpEntity, PromQlQueryContent.class);
+                HttpMethod.GET, httpEntity, PromQlQueryContent.class);
             if (responseEntity.getStatusCode().is2xxSuccessful()) {
                 if (responseEntity.getBody() != null && responseEntity.getBody().getData() != null
-                        && responseEntity.getBody().getData().getResult() != null) {
+                    && responseEntity.getBody().getData().getResult() != null) {
                     List<PromQlQueryContent.ContentData.Content> contents = responseEntity.getBody().getData().getResult();
                     for (PromQlQueryContent.ContentData.Content content : contents) {
                         Map<String, String> labels = content.getMetric();
                         labels.remove(LABEL_KEY_NAME);
                         labels.remove(LABEL_KEY_JOB);
                         labels.remove(LABEL_KEY_INSTANCE);
+                        labels.remove(LABEL_KEY_MONITOR_ID);
                         labels.remove(MONITOR_METRICS_KEY);
                         labels.remove(MONITOR_METRIC_KEY);
                         String labelStr = JsonUtil.toJson(labels);
@@ -451,22 +459,25 @@ public class VictoriaMetricsDataStorage extends AbstractHistoryDataStorage {
             }
             // min
             uri = UriComponentsBuilder.fromUriString(victoriaMetricsProp.url() + QUERY_RANGE_PATH)
-                    .queryParam(URLEncoder.encode("query", StandardCharsets.UTF_8), URLEncoder.encode("min_over_time({" + timeSeriesSelector + "})", StandardCharsets.UTF_8))
-                    .queryParam("step", "4h")
-                    .queryParam("start", startTime)
-                    .queryParam("end", endTime)
-                    .build(true).toUri();
+                .queryParam("query", "min_over_time({" + timeSeriesSelector + "})")
+                .queryParam("step", "4h")
+                .queryParam("start", startTime)
+                .queryParam("end", endTime)
+                .build()
+                .encode()
+                .toUri();
             responseEntity = restTemplate.exchange(uri,
-                    HttpMethod.GET, httpEntity, PromQlQueryContent.class);
+                HttpMethod.GET, httpEntity, PromQlQueryContent.class);
             if (responseEntity.getStatusCode().is2xxSuccessful()) {
                 if (responseEntity.getBody() != null && responseEntity.getBody().getData() != null
-                        && responseEntity.getBody().getData().getResult() != null) {
+                    && responseEntity.getBody().getData().getResult() != null) {
                     List<PromQlQueryContent.ContentData.Content> contents = responseEntity.getBody().getData().getResult();
                     for (PromQlQueryContent.ContentData.Content content : contents) {
                         Map<String, String> labels = content.getMetric();
                         labels.remove(LABEL_KEY_NAME);
                         labels.remove(LABEL_KEY_JOB);
                         labels.remove(LABEL_KEY_INSTANCE);
+                        labels.remove(LABEL_KEY_MONITOR_ID);
                         labels.remove(MONITOR_METRICS_KEY);
                         labels.remove(MONITOR_METRIC_KEY);
                         String labelStr = JsonUtil.toJson(labels);
@@ -486,22 +497,25 @@ public class VictoriaMetricsDataStorage extends AbstractHistoryDataStorage {
             }
             // avg
             uri = UriComponentsBuilder.fromUriString(victoriaMetricsProp.url() + QUERY_RANGE_PATH)
-                    .queryParam(URLEncoder.encode("query", StandardCharsets.UTF_8), URLEncoder.encode("avg_over_time({" + timeSeriesSelector + "})", StandardCharsets.UTF_8))
-                    .queryParam("step", "4h")
-                    .queryParam("start", startTime)
-                    .queryParam("end", endTime)
-                    .build(true).toUri();
+                .queryParam("query", "avg_over_time({" + timeSeriesSelector + "})")
+                .queryParam("step", "4h")
+                .queryParam("start", startTime)
+                .queryParam("end", endTime)
+                .build()
+                .encode()
+                .toUri();
             responseEntity = restTemplate.exchange(uri,
-                    HttpMethod.GET, httpEntity, PromQlQueryContent.class);
+                HttpMethod.GET, httpEntity, PromQlQueryContent.class);
             if (responseEntity.getStatusCode().is2xxSuccessful()) {
                 if (responseEntity.getBody() != null && responseEntity.getBody().getData() != null
-                        && responseEntity.getBody().getData().getResult() != null) {
+                    && responseEntity.getBody().getData().getResult() != null) {
                     List<PromQlQueryContent.ContentData.Content> contents = responseEntity.getBody().getData().getResult();
                     for (PromQlQueryContent.ContentData.Content content : contents) {
                         Map<String, String> labels = content.getMetric();
                         labels.remove(LABEL_KEY_NAME);
                         labels.remove(LABEL_KEY_JOB);
                         labels.remove(LABEL_KEY_INSTANCE);
+                        labels.remove(LABEL_KEY_MONITOR_ID);
                         labels.remove(MONITOR_METRICS_KEY);
                         labels.remove(MONITOR_METRIC_KEY);
                         String labelStr = JsonUtil.toJson(labels);
@@ -593,7 +607,7 @@ public class VictoriaMetricsDataStorage extends AbstractHistoryDataStorage {
         }
         // Refresh in advance to avoid waiting
         if (metricsBufferQueue.size() >= insertConfig.bufferSize() * 0.8
-                && draining.compareAndSet(false, true)) {
+            && draining.compareAndSet(false, true)) {
             triggerImmediateFlush();
         }
     }
@@ -659,7 +673,7 @@ public class VictoriaMetricsDataStorage extends AbstractHistoryDataStorage {
             HttpHeaders headers = new HttpHeaders();
             headers.setContentType(MediaType.APPLICATION_JSON);
             if (StringUtils.hasText(victoriaMetricsProp.username())
-                    && StringUtils.hasText(victoriaMetricsProp.password())) {
+                && StringUtils.hasText(victoriaMetricsProp.password())) {
                 String authStr = victoriaMetricsProp.username() + ":" + victoriaMetricsProp.password();
                 String encodedAuth = Base64Util.encode(authStr);
                 headers.add(HttpHeaders.AUTHORIZATION,  NetworkConstants.BASIC + SignConstants.BLANK + encodedAuth);
@@ -688,7 +702,7 @@ public class VictoriaMetricsDataStorage extends AbstractHistoryDataStorage {
             }
 
             ResponseEntity<String> responseEntity = restTemplate.postForEntity(victoriaMetricsProp.url() + IMPORT_PATH,
-                    httpEntity, String.class);
+                httpEntity, String.class);
             if (responseEntity.getStatusCode().is2xxSuccessful()) {
                 log.debug("insert metrics data to victoria-metrics success.");
             } else {
