@@ -20,8 +20,8 @@
 export class AlertDefine {
   id!: number;
   name!: string;
-  // realtime, periodic
-  type: string = 'realtime';
+  // realtime_metric, periodic_metric, realtime_log, periodic_log
+  type: string = 'realtime_metric';
   // datasource when type is periodic, promql | sql
   datasource: string = 'promql';
   expr!: string;
